require 'logging'

module Logging
  # Preconfigured set of log levels for verbose logging.
  #
  # @see #verbose_init
  VERBOSE_LEVELS = [:verbose, :debug, :info, :warn, :error, :fatal]

  # Initializes the global logger with the default set of log levels.
  #
  # @see http://www.rubydoc.info/gems/logging/Logging#init-class_method
  #
  # @param [TrueClass, FalseClass] reset Pass `true` to reset the global logging configuration to its default state.
  def self.init_verbose_levels(reset: false)
    # Don't do anything as the global logger has been initialized somewhere else
    if Logging.initialized? && !reset
      return log_internal { "Cannot initialize verbose logging as logging is already initialized." }
    end

    # Reset the global logging state if requested
    Logging.reset if reset

    # Initialize with verbose levels
    Logging.init(VERBOSE_LEVELS)
  end
end
